Package: roxutTestPkg
Type: Package
Title: Simple Package for Testing roxut Package
Version: 0.1
Date: 2020-05-29
Authors@R: c(
    person("Bryan A.", "Hanson",
           role = c("aut", "cre"),
           email = "hanson@depauw.edu",
           comment = c(ORCID = "0000-0003-3536-8246"))
           )
Description: Provides testing infrastructure for the 'roxut' package.  Includes tests for proper functioning with 'tinytest' and 'testthat' frameworks.  Package structure is minimal, after processing with 'roxut' via 'roxygen2' additional directories and files will be added.
License: GPL-3
Encoding: UTF-8
Suggests:
  tinytest,
  testthat
RoxygenNote: 7.1.0
