# Generated by roxygen2: do not edit by hand

S3method(roclet_clean,roclet_tests)
S3method(roclet_output,roclet_tests)
S3method(roclet_process,roclet_tests)
S3method(roxy_tag_parse,roxy_tag_tests)
export(tests_roclet)
import(roxygen2)
importFrom(stats,na.omit)
